#' @importFrom sjlabelled write_spss
#' @importFrom sjlabelled write_stata
#' @importFrom sjlabelled write_sas
#' @importFrom WriteXLS WriteXLS
#' @importFrom dplyr select
#' @importFrom readr write_tsv
#' @importFrom tibble is_tibble
#'
#'
#' @title Export GEDII data to various data formats
#'
#' @description Utility function to export the GEDII team level and individual level data to various
#'  other data formats such as SPSS, STATA, SAS, Excel or CSV files. The export functionality also
#'  makes a selection of variables from the original dataset.
#'
#' @param path string. The path and file name to the file to be exported.
#' @param src Can be either a data frame with gedii data or a string ["gedii_tld" | "gedii_ccs" | "gedii_ccsb" | "gedii_tldb]
#'  indicating the source dataset to be used for exporting. Default is team level data.
#' @param format string. Vector of target data format(s). Support formats are ["SPSS", "STATA", "SAS", "XLS", "CSV"]
#' @param vars string. Vector of variable names to be selected for exporting. Default variable
#'   names for team level data is provided. The specified variables have to match the data source of course.
#'
#' @return Data frame with selected variables. The corresponding data file in the specified format has
#'   been written to the specified distination.
#'
#' @export
#'

export_gedii <- function(path, src="gedii_tld", format="SPSS", vars=NULL, ...){

  if (is.data.frame(src) | tibble::is_tibble(src)){
    df.src <- src

  } else if (src == "gedii_tld"){
    df.src <- gedii_tld

  } else if (src == "gedii_ccs"){
    df.src <- gedii_ccs

  } else if (src == "gedii_ccsb"){
    df.src <- gedii_ccsb

  } else if (src == "gedii_tldb"){
    df.src <- gedii_tldb

  } else {
    stop("Unknown data source. src needs to be 'tld' or 'ccs' or data frame.")
  }


  if (is.null(vars) & (src == "gedii_tld" | src == "gedii_tldb")){

    vars <- c("v_1",
              "GroupNumber",
              "TL_NrSeniorBib_Nov18",
              "TL_PercSeniorBib_Nov18",
              "OrgTypeR_Nov18",            ## Block 1 Team context
              "CountryBib_Nov18",
              "Applied_Nov18",
              "TeamType_Nov18",            ## Block 2 Team composition
              "TL_TimePub",
              "teamsize_recruited",
              "teamsize_bib",
              "teamsize",
              "ColocationBib_Nov18",
              "InwardNorm_Nov18",
              "InwardNormMedian_Jan19",
              "TL_NrSeniorRole",
              "TL_PercSeniorRole",
              "TL_NrMARole",
              "TL_PercMARole",
              "TL_NrPhDRole",
              "TL_PercPhDRole",
              "TL_NrAdminRole",
              "TL_PercAdminRole",
              "TL_NrPostdocRole",
              "TL_PercPostddocRole",
              "TL_NrAssistantRole",
              "TL_PercAssistantRole",
              "TL_NrJuniorRole",
              "TL_PercJuniorRole",
              "TL_NrNonBibRole",
              "TL_NrWomenNonBibRole",
              "TL_NrMenNonBibRole",
              "TL_PercNonBibRole",
              "TL_NrBib",
              "TL_PercBib",
              "TL_NrSeniorExp",
              "TL_PercSeniorExp",
              "TL_Ethnic",
              "TL_PercEthnic",
              "TL_Disability",
              "TL_PercDisability",
              "TL_CareRespPresent",
              "TL_CareRespPast",
              "TL_CareResp",
              "TL_PercCareResp",
              "TL_CareDoesAffect",
              "TL_PercCareDoesAffect",
              "TL_NrMentors",
              "TL_PercMentors",
              "TL_Tclimate",               ## Block 3 Team culture
              "TL_Wclimate",
              "TL_PInfluDisp",
              "TL_DisciplinHQVar",
              "TL_Leadstyle",
              "TL_YrsInTeam",              ## Block 4 Team dynamics
              "TL_Age",
              "TL_NrPermContract",
              "TL_PercPermContract",
              "TL_NrTempContract",
              "TL_PercTempContract",
              "TL_NrWomen",                ## Block 5 Gender of recruited team.
              "TL_NrMen",
              "TL_PercWomen",
              "TL_PercMen",
              "TL_GenderBalance",
              "TL_NrWomenSeniorBib",       ## Gender of Seniors bib only
              "TL_NrMenSeniorBib",
              "TL_PercWomenSeniorBib",
              "TL_PercMenSeniorBib",
              "TL_GenderBalanceSeniorBib",
              "TL_NrWomenBib",             ## Gender of Bib team only (not just bib seniors)
              "TL_NrMenBib",
              "TL_PercWomenBib",
              "TL_PercMenBib",
              "TL_GenderBalanceBib",
              "TL_GenderLeader",           # Gender of team leader
              "TL_Gstereo",
              "Index.6",
              "Seniority_attrition",
              "Seniority_blauH",
              "Seniority_score",
              "Tenure_attrition",
              "Tenure_blauH",
              "Tenure_score",
              "CareCurrent_attrition",
              "CareCurrent_blauH",
              "CareCurrent_score",
              "Contract_attrition",
              "Contract_blauH",
              "Contract_score",
              "Education_attrition",
              "Education_blauH",
              "Education_score",
              "Marital_attrition",
              "Marital_blauH",
              "Marital_score",
              "AgeAv_attrition",
              "AgeAv_blauH",
              "AgeAv_score",
              "FAP5Y1000_Nov18",          ## Performance measures
              "FAP5Y1000xNrSeniorBib_Nov18",
              "PMM5Y1000_Nov18",
              "PMM5Y1000xNrSeniorBib_Nov18")

  }


  if (is.null(vars)) {
    stop("No column names selected for export")
  }

  # select the columns from the source data frame
  df <- df.src %>%
    dplyr::select(vars)


  if (nrow(df) == 0 | ncol(df) == 0) {
    warning("Result data frame is empty!")
  }


  if (format == "SPSS") {

    sjlabelled::write_spss(df, path, ...)

  } else if (format == "STATA") {

    sjlabelled::write_stata(df, path, ...)

  } else if (format == "SAS") {

    sjlabelled::write_sas(df, path, ...)

  } else if (format == "XLS") {

    WriteXLS::WriteXLS(list(df), ExcelFileName=path, SheetNames = c("All"), ...)

  } else if (format == "CSV") {

    readr::write_csv(df, path=path)

  } else {
    warning("Unknown file format. Nothing written")

  }


  invisible(df)

}
