#' Code for pre-processing the raw SPSS result data sets from the [GEDII](http://www.gedii.eu)
#' cross-country survey on gender diversity in research teams. Raw data files have been downloaded
#' from the Questback survey platform as "SPSS (labeled data file in SPSS binary format)" format.
#'
#' Several questionnaires have been used accomodating "personalized" and "anonymous"
#' versions, respecting different team response preferences. An additional, short
#' team contact questionnaire contains global information of each team, filled out by
#' a team contact person.
#'
#' The following shortcuts for the three datasets are used:
#'
#' ccsp - personalized team survey data
#' ccsa - anonymous team survey data
#' ccsc - contact survey data
#' ccsi - anonymous team survey 2
#'
#'
#' In addition, the surey dataframe is combined with the results of the bibliometric
#' analysis of the research teams.
#'
#' df.perf - Dataframe with bibliometric performance indicators, patent performance data
#'
#'
#' ccs  - merged dataset of ccsp + ccsa + ccsi + bibliometric/patents + ccsc
#'
#' As new survey data becomes available, several external files need updating before running
#' this script.
#'
#' 1. If new teams have been added, the number of team members and participation is stored in
#' "teamsize.csv". This file is updated by running the GEDII_xcountry_participation.R script first
#' and then just saving the TeamID and Total columns from the TOTALRES sheet.
#'
#' 2. Any performance data Excel files for bibliometric and patent indicators. It uses all xls files
#' inside the "performance/group xls/ folder. The global metrics stored in the "Results_Bibliometrics_..."
#' and "Results_Patens_...." files.
#'
#'
#' Please consult CHANGELOG to important information regarding data pre-processing and versioning.
#'



rm(list=ls())
gc()


#' Load required libraries
library(sjlabelled)
library(sjPlot)

library(tidyverse)

#' these are part of the tidyverse but not attached automatically
library(magrittr)
library(stringr)
library(readxl)

library(gpg)





#' Custom function to X-out certain parts of strings where plain names are given
#' or other information that would allow to identify respondent.
#' @param rid String, row id string; alphanumeric "a|b|c000"
#' @param varname String variable name to x-out
#' @param xstart Number. Character position of the string where X-out starts
#' @param xstop Number. Character position where X-out stops
#'
#' Replacements are written directly into the "ccs" data frame.
xout <- function(rid, varname, xstart, xstop){
  txt <- as.character(ccs[ccs$rowid==rid, varname])
  len <- xstop - xstart

  substr(txt, xstart, xstop) <- paste(rep("X",len), collapse="")
  ccs[ccs$rowid==rid, varname] <<- txt
}


#' Utility function to store raw data as encrypted dataframes.
#' Only used upon first usage of raw data. Rest of preprocessing then
#' relies on encrypted dataframes directly.
#' @param df The data frame to be encrypted
#' @param file String. Name and path for writing file
#' @param id of gpg key used for encryption
#'
write_gpg <- function(df, file="df.gpg", receiver="jmuller@uoc.edu"){
  df.s <- serialize(df, con=NULL, ascii=T)
  df.enc <- gpg_encrypt(df.s, receiver=receiver)
  writeBin(df.enc, con=file)
}

#' Read encrypted dataframe and unserialize
#'
#' @param file String. File path of file to be decrypted
read_gpg <- function(file, as_text=FALSE){
  df <- gpg_decrypt(file, as_text=as_text)
  df <- unserialize(df)
  df
}



#' Current year used to calculate team tenure and age
current_year <- as.numeric(format(Sys.Date(), "%Y"))


#' Two datasets can be created:
#'
#' "recruited" will produce the original dataset including all questionnaire submissions based
#' upon the team recruitment process. This will produce the "gedii_ccs" data file.
#'
#' If set to "bib" it reflects the teamsize minus those likely members that could not contribute
#' to the publication record of the team either because they are junior roles or are too young.
#' The rule is on line 1107 in the build_gediiccs.R script and based upon v_12R (team role):
#' isNonBibRole    = if_else((Age < 29 & v_11 > 2014) | (v_12R == 1 | v_12R == 8), 1, 0))
#' Team members that are younger than 29 years or have joined the team after 2014 and which are either
#' role = Admin, MA.
#'
#' In case the "bib" dataset is build, the NonBibRole members will be removed, teamsize accordingly
#' adjusted which also potentially affects all teamsize dependent variables such as NrMentors,
#' NrPhD, etc. The dataset created will be "gedii_ccsb"

#tss_type <- "bib"
tss_type <- "recruited"



#' Load SPSS survey data.
#' These are the original Questback files. Since these files do not change anymore
#' all following pre-processing scripts load the raw data fromt the encrypted files
#'
#' Read encrypted data frames of raw SPSS data. Avoids to store
#' raw data on disc.
#'
#' NOTE: raw data files - even if encrypted - are not included in the Open Access
#'       version of the gediiccs package.
#'
ccsc <- read_gpg("data-raw/df.ccsc.gpg")
ccsa <- read_gpg("data-raw/df.ccsa.gpg")
ccsp <- read_gpg("data-raw/df.ccsp.gpg")
ccsi <- read_gpg("data-raw/df.ccsi.gpg")



#' In order to identify a persistent ID for each row, a combined new column is created
#' that uses the "lfdn" column (the internal ID from the survey platform) with a simple
#' distinction for the three source data files, ie. the personalized, and the two anonymous
#' datasets that are eventually merged into one data frame. This is necessary in order to be
#' flexible with respect to new entries to these respective datasets at a later point in time
#' without having to revise the recodifications of text fields and corrections at specific rows.
#'
#' We just add an extra column indicating a,b,c for the three source files and then construct
#' a combined ID from the source + ldfn number. This column should be used for referencing rows
#' in subsequent steps.
ccsp$surveysrc <- "a"
ccsa$surveysrc <- "b"
ccsi$surveysrc <- "c"

ccsp$rowid <- paste0(ccsp$surveysrc, ccsp$lfdn)
ccsa$rowid <- paste0(ccsa$surveysrc, ccsa$lfdn)
ccsi$rowid <- paste0(ccsi$surveysrc, ccsi$lfdn)




#' TEAM CONTACT
#'

#' delete double entries, i.e. team contact was submitted
#' more than once. The following entries are removed from the dataframe
#' after manually comparing available data with public profile of groups
ccsc <- filter(ccsc, !(lfdn %in% c(91,65,66,14,20,22,23,24,39,76,126,135)))


#' FIXING  TEAM CONTACT
#'
#' XXXXX glitch. Group code was XXXXX but real code has been deduced:
ccsc[which(ccsc$lfdn == 111), "p_0001"] <- "PM88M1642U"
ccsc[which(ccsc$lfdn == 163), "p_0001"] <- "NM84T1048U"
ccsc[which(ccsc$lfdn == 155), "p_0001"] <- "YT96T1739U"
ccsc[which(ccsc$lfdn == 168), "p_0001"] <- "WM132M1600U"
ccsc[which(ccsc$lfdn == 170), "p_0001"] <- "ZM136T1132U"
ccsc[which(ccsc$lfdn == 176), "p_0001"] <- "NM138T1714U"
ccsc[which(ccsc$lfdn == 215), "p_0001"] <- "ZM148M1235U"



#' check how many entries are available for following code. Should
#' be just one. Code has been given to two different team contacts, but the second
#' erroneous one has not answered. The first one is correct. If two entries appear, the
#' second needs to be corrected.
ccsc %>%
  filter(v_1 == "OT106T1456U" | p_0001 == "OT106T1456U") %>%
  select(dispcode, v_1, p_0001)


#' Remove testers and remaining XXXXX
ccsc <- filter(ccsc, tester==0) #remove testers
ccsc <- filter(ccsc, p_0001 != "XXXXX" & p_0001 != "XXXXXXXX" & p_0001 != "asdfasdfasdf")

ccsc$p_0001 <- trimws(ccsc$p_0001)

ccsc <- select(ccsc, c(1,8:21,23:29))

#'remove empty rows. Could also be done via dispcode
numNAs <- rowSums(is.na(ccsc))
ccsc <- filter(ccsc, numNAs < 13)

#' change column names to not overlap with v_1, v_2 of team member results
names(ccsc) <- c("lfdn", "GroupCode", "TC_OrgType", "TC_OrgTypeOther", "TC_NumEmployees", "TC_NrWomen", "TC_NrMen",
                 "TC_Topic", "TC_FoundingYear", "TC_Method", "TC_MethodOther", "TC_Colocation", "TC_GEP",
                 "TC_GenderDim", "TC_GenderDimSpecify", "TC_RRI_Ethics", "TC_RRI_Gender", "TC_RRI_Gov",
                 "TC_RRI_OA", "TC_RRI_Pub", "TC_RRI_SciEdu", "TC_RRI_DKnow")





#' PERSONALIZED PE
#'
#' Load team code mapping table for personalized survey.
#' Questback stores group codes with an internal number starting from 1....n. This
#' does not match our project team codes and needs to be replaced. The group code
#' identifies each response as pertaining to a certain team.
#'
#' Create a "factor" where "-66" is replaced with NA.



#' FIXES - PE
#'
#' Group code is plain name. Needs to be replaced with actual code
ccsp[which(ccsp$rowid=="a654"), "v_1"] <- 67  #fix group code, being plain name?!
ccsp[which(ccsp$rowid=="a713"), "v_1"] <- 71  #fix group code, spelling mistake

#' Each member got erroneously different team code
#' Recode YM110M1336 to YM110M1335U
#' Recode YM110M1337 to YM110M1335U
#' Recode YM110M1338 to YM110M1335U
ccsp[which(ccsp$v_1 == 101), "v_1"] <- 100
ccsp[which(ccsp$v_1 == 102), "v_1"] <- 100
ccsp[which(ccsp$v_1 == 103), "v_1"] <- 100


#' Build team code
#teamcode <- read_tsv("~/limbo/GEDII/lfn2groupcode_PE.csv")
teamcode <- read_gpg("data-raw/df.lfn2groupcode_PE.gpg")


#' Fix misspellings of team code. Missing letters when distributed.
teamcode[which(teamcode$external == "W115T1507U"), "external"] <- "WT115T1507U"
teamcode[which(teamcode$external == "Z116T1628U"), "external"] <- "ZT116T1628U"
teamcode[which(teamcode$external == "R117T1654U"), "external"] <- "RM117T1654U"
teamcode[which(teamcode$external == "OT104T1253U"),"external"] <- "CT104T1253U"

lev <- c(-66, teamcode$internal)
lab <- c(NA, teamcode$external)
ccsp$v_1 <- factor(ccsp$v_1, levels=lev, labels=lab)



#' ANONYMOUS AN
#'
#' 1. ccsa has an extra column p_0001 which contains the team code as URL parameter. This value is
#' not copied into team code column (v_1) in case users visited landing page but nothing else,
#' showing a "-66".
#'
#' Here, we first copy this value into v_1 (team code) in order to not loose this information
#' and then delete the p_0001 column
#'
ccsa$v_1 <- ccsa$p_0001
ccsa$v_1 <- trimws(ccsa$v_1)  #remove whitespace
ccsa <- select(ccsa, -c(8))   #remove p_0001 colum


#' FIXING ANONYMOUS AN
#'
#' Delete from AN entry with code: UM82W1108U - see email efrem 6 NOV 2017
#' However, team does not reach reponse rate and is taken out anyway.

#' Replace team code "BT85T1225U" with "UT85T1225U". This team is from Belgium, not UK!
ccsa[which(ccsa$v_1 == "BT85T1225U"), "v_1"] <- "UT85T1225U"

#' Take out XXXXXX as group code
ccsa <- filter(ccsa, v_1 != "XXXXXX" & v_1 != "XXXXXXXX")

#' Remove one submission of withdrawn group
ccsa <- filter(ccsa, v_1 != "EM37M0911U")



#' 2. Remove meta-data user information (browser, flash, javascript, etc. ) and rts-columns
#' which do not match from both datases.
#'
ccsp <- select(ccsp, -c(122:160))
ccsa <- select(ccsa, -c(122:160))


# nrow(ccsa)
# unique(ccsa$dispcode)
# nrow(filter(ccsa, dispcode > 30))



#' 3. Prepare 2nd anonymous survey for merging. This is the same as the anonymous survey but extended with
#' additional questions that need to be removed before mering into the global file.
#'

#' Two entries of research group are "other", but recodify to specific group.
ccsi[ccsi$rowid=="c47","v_277"] <- 8
ccsi[ccsi$rowid=="c145","v_277"] <- 13


#' Remove non-research group respondents
ccsi <- filter(ccsi, v_277!=19)

#' Remove duplicate entries for specific group
ccsi <- filter(ccsi, !(rowid %in% c("c202", "c203", "c204", "c214")))


#' Create team codes as a factor
#teamcode2 <- read_tsv("~/limbo/GEDII/lnf2groupcode_AN2_I.csv")
teamcode2 <- read_gpg("data-raw/df.lnf2groupcode_AN2_I.gpg")
lev <- c(0, teamcode2$ID)
lab <- c(NA, teamcode2$TeamID)
ccsi$v_1 <- factor(ccsi$v_277, levels=lev, labels=lab)



#' Remove extra variables + metadata information
ccsi <- select(ccsi, -c(v_277, v_279), -num_range("v_",c(224:251, 255, 256, 257)), -num_range("v_", c(260:266, 268, 269)))
ccsi <- select(ccsi, -c(122:148))



#' 4. Merge the three datasets into one "ccs"
#'
ccsp$v_1 <- as.character(ccsp$v_1) #team id coerce to character for merging
ccsi$v_1 <- as.character(ccsi$v_1)
ccs <- rbind(ccsp, ccsa)
ccs <- rbind(ccs, ccsi)


#' 5. Remove any plain names from text fields. var_char variables are selected for
#' tmp dataframe and written to xls for manual checking.
#'
#' This step, specifically writing out the char fields and checking for plain names
#' has to be repeated by writing out the dataframe as exel if new entries are added
#' to any of the three datasets.
#'
xout("a535","v_18", 57,73)
xout("a89","v_18", 23,39)
xout("a635","v_71", 11,24)
xout("b133", "v_214", 10, 171)
xout("a562", "v_214", 107, 121)



#' 6. Replace 0s, -66, -99 with NA for listed variables
#'
zero2NA <- c("v_4", "v_5", "v_6", "v_7", "v_9", "v_10", "v_11", "v_12", "v_13", "v_14", "v_15",
             "v_16", "v_17", "v_143", "v_144", "v_145", "v_63", "v_64", "v_95", "v_100", "v_101",
             "v_102", "v_123", "v_130", "v_131", sprintf("v_%d", 151:164), sprintf("v_%d", 170:180),
             sprintf("v_%d", 186:189), sprintf("v_%d", 80:87), sprintf("v_%d", 195:198))

for (var in zero2NA){
  ccs[,var] <- na_if(ccs[,var], 0)
  ccs[,var] <- na_if(ccs[,var], -66)
  ccs[,var] <- na_if(ccs[,var], -99)
}






#' Plausibility checks and recodifications
#'
#' To inspect lables for factors, write (for example for v_4) attr(ccs$v_4, "labels")
#'
#'

#' v_4 Highest level of education
#' Print "Other, please specify" values to see how to to recodify:
ccs %>% filter(as.numeric(v_4)==5) %>% select(rowid, v_222)

#print available lables
attr(ccs$v_4, "labels")

#recodify variable into v_4R
ccs$v_4R <- ccs$v_4

ccs[ccs$rowid=="a200", "v_4R"] <- 2 # replace HNC by Bachelors
ccs[ccs$rowid=="a193", "v_4R"] <- 2 # replace PgC by Bachelors
ccs[ccs$rowid=="a432", "v_4R"] <- 2 # replace 95% of MSc by Bachelors
ccs[ccs$rowid=="a379", "v_4R"] <- 2 # replace Degree by Bachelors
ccs[ccs$rowid=="a446", "v_4R"] <- 2 # replace upper degree by Bachelors
ccs[ccs$rowid=="a538", "v_4R"] <- 3 # replace PhD student by Masters
ccs[ccs$rowid=="a515", "v_4R"] <- 4 # replace Ass Prof by NA
ccs[ccs$rowid=="a772", "v_4R"] <- 4 # replace Leg Lakare by Doctorate
ccs[ccs$rowid=="a543", "v_4R"] <- 4 # replace MD by Doctorate
ccs[ccs$rowid=="a493", "v_4R"] <- 4 # replace docent by Doctorate
ccs[ccs$rowid=="a737", "v_4R"] <- 3 # replace Diploma and professional by Masters
ccs[ccs$rowid=="a616", "v_4R"] <- 2 # replace 5th year diploma by Bachelors
ccs[ccs$rowid=="a759", "v_4R"] <- 3 # replace FPII grado superior by Masters
ccs[ccs$rowid=="a763", "v_4R"] <- 3 # replace Diploma by Masters
ccs[ccs$rowid=="b99", "v_4R"]  <- 2 # replace Vocational training by Bachelors ??
ccs[ccs$rowid=="b214", "v_4R"] <- 3 # replace PhD student by Masters
ccs[ccs$rowid=="b249", "v_4R"] <- 4 # replace MD by Doctorate
ccs[ccs$rowid=="b289", "v_4R"] <- 3 # replace Dip Ing by Masters
ccs[ccs$rowid=="b291", "v_4R"] <- 3 # replace German
ccs[ccs$rowid=="a881", "v_4R"] <- 3 # replace M.Sc with Master
ccs[ccs$rowid=="b317", "v_4R"] <- 3 # replace PhD candiate with Master
ccs[ccs$rowid=="b372", "v_4R"] <- 3 # replace MTRA, DAS
ccs[ccs$rowid=="a1225", "v_4R"] <- 3# replace Chemie lab technician
ccs[ccs$rowid=="a1253", "v_4R"] <- 4# full professor


#' everything recodified? List should be empty now
ccs %>% filter(as.numeric(v_4R)==5) %>% select(rowid, v_222)



#' v_5 Discipline of your highest qualification
#'
#' 1	Chemistry, Physics & Engineering
#' 2	Life Science & Medical Science
#' 3	Sociology, Economics & Political Science
#' 4	Computer Science & Mathematics
#' 5	Psychology & Education
#' 6	Agriculture & Food Science
#' 7	Biology, Environmental Science & Geography
#' 8	Humanities
#' 10	Other, please specify:
#'
#' See attr(ccs$v_5, "labels")
#'
#' Print "Other":
ccs %>% filter(as.numeric(v_5)==10) %>% select(rowid, v_223)

#' recodify v_5 to v_5R
ccs$v_5R <- ccs$v_5

ccs[ccs$rowid=="a108", "v_5R"] <- 8 # English Humanities
ccs[ccs$rowid=="a200", "v_5R"] <- 3 # Administration
ccs[ccs$rowid=="a95", "v_5R"] <- 1  # Biomed Eng
ccs[ccs$rowid=="a237", "v_5R"] <- 1 # Mech Eng
ccs[ccs$rowid=="a85", "v_5R"] <- 3  # Management
ccs[ccs$rowid=="a81", "v_5R"] <- 3  # Law
ccs[ccs$rowid=="a159", "v_5R"] <- 3 # Management
ccs[ccs$rowid=="a70", "v_5R"] <- 1  # Economics & Electrical Engineer
ccs[ccs$rowid=="a71", "v_5R"] <- 1  # Civil Eng
ccs[ccs$rowid=="a135", "v_5R"] <- 1 # Biomed Eng
ccs[ccs$rowid=="a188", "v_5R"] <- 1 # Telecom Eng
ccs[ccs$rowid=="a212", "v_5R"] <- 2 # Medical technical assistant
ccs[ccs$rowid=="a354", "v_5R"] <- 1 # Nanotech
ccs[ccs$rowid=="a253", "v_5R"] <- 1 # Technological science
ccs[ccs$rowid=="a406", "v_5R"] <- 2 # Dentristy
ccs[ccs$rowid=="a344", "v_5R"] <- 7 # Aquaculture and fish diseas. Also 6??
ccs[ccs$rowid=="a299", "v_5R"] <- 7 # Biochemistry. Also 1??
ccs[ccs$rowid=="a262", "v_5R"] <- 1 # Life science & engineering
ccs[ccs$rowid=="a309", "v_5R"] <- 1 # Material science
ccs[ccs$rowid=="a308", "v_5R"] <- 7 # Computational biology. Also 4??
ccs[ccs$rowid=="a359", "v_5R"] <- 7 # Biochemistry. Also 1??
ccs[ccs$rowid=="a515", "v_5R"] <- 1 # Biomed Eng
ccs[ccs$rowid=="a457", "v_5R"] <- 4 # Math statistics
ccs[ccs$rowid=="a440", "v_5R"] <- 2 # Physiotherapy
ccs[ccs$rowid=="a545", "v_5R"] <- 3 # Business admin
ccs[ccs$rowid=="a658", "v_5R"] <- 3 # Business economics
ccs[ccs$rowid=="a514", "v_5R"] <- 7 # Logistics. Also 4??
ccs[ccs$rowid=="a564", "v_5R"] <- 7 # Transport systems
ccs[ccs$rowid=="a522", "v_5R"] <- 7 # Transport science
ccs[ccs$rowid=="a537", "v_5R"] <- 2 # Health science
ccs[ccs$rowid=="a511", "v_5R"] <- 8 # Design sciences.
ccs[ccs$rowid=="a716", "v_5R"] <- 2 # Caring science
ccs[ccs$rowid=="a664", "v_5R"] <- 6 # Forestry (social dimension)
ccs[ccs$rowid=="a626", "v_5R"] <- 6 # Forest management. Also 7??
ccs[ccs$rowid=="a655", "v_5R"] <- 2 # Public health
ccs[ccs$rowid=="a575", "v_5R"] <- 4 # Statistics
ccs[ccs$rowid=="a665", "v_5R"] <- 8 # Dance
ccs[ccs$rowid=="a585", "v_5R"] <- NA# Interdisciplinary
ccs[ccs$rowid=="a561", "v_5R"] <- 3 # Medical anthropology (soc sci)
ccs[ccs$rowid=="a572", "v_5R"] <- 3 # Sociology/policy studies
ccs[ccs$rowid=="a562", "v_5R"] <- 1 # Biomed eng
ccs[ccs$rowid=="a597", "v_5R"] <- 7 # Biotechnology. Also 1??
ccs[ccs$rowid=="a666", "v_5R"] <- 2 # Public health
ccs[ccs$rowid=="a672", "v_5R"] <- 1 # Civil Eng
ccs[ccs$rowid=="a687", "v_5R"] <- 1 # Economics & Engineering
ccs[ccs$rowid=="a681", "v_5R"] <- NA# Spatial Planning
ccs[ccs$rowid=="a680", "v_5R"] <- 1 # Engineering
ccs[ccs$rowid=="a690", "v_5R"] <- 1 # Mobility Eng
ccs[ccs$rowid=="a764", "v_5R"] <- 3 # Business admin
ccs[ccs$rowid=="a763", "v_5R"] <- 8 # Language Translation
ccs[ccs$rowid=="a765", "v_5R"] <- 3 # Management
ccs[ccs$rowid=="a781", "v_5R"] <- 3 # Management
ccs[ccs$rowid=="b47", "v_5R"] <-  3 # Administration
ccs[ccs$rowid=="b122", "v_5R"] <- 5 # Human factors??
ccs[ccs$rowid=="b124", "v_5R"] <- 5 # Human factors??
ccs[ccs$rowid=="b133", "v_5R"] <- 7 # Geography
ccs[ccs$rowid=="b161", "v_5R"] <- 1 # Mech Eng
ccs[ccs$rowid=="b237", "v_5R"] <- 7 # Computational Biology. Also 4?!
ccs[ccs$rowid=="b259", "v_5R"] <- 3 # Law
ccs[ccs$rowid=="b291", "v_5R"] <- 1 # automobile mechanic
ccs[ccs$rowid=="c65", "v_5R"] <-  1 # Biochemistry. Also 7??
ccs[ccs$rowid=="a880", "v_5R"] <- 3 # Interational Business
ccs[ccs$rowid=="a906", "v_5R"] <- 4 # Human-Computer Interaction
ccs[ccs$rowid=="a891", "v_5R"] <- 7 # Bioinformatics. Also 4?!
ccs[ccs$rowid=="a881", "v_5R"] <- 1 # Biomedical Engineering
ccs[ccs$rowid=="a931", "v_5R"] <- 2 # Dentistry
ccs[ccs$rowid=="a940", "v_5R"] <- 2 # Oral surgery
ccs[ccs$rowid=="a948", "v_5R"] <- 1 # Electronics and Information Technology
ccs[ccs$rowid=="a1025","v_5R"] <- 7 # Architecture - Environmental Design
ccs[ccs$rowid=="a1014","v_5R"] <- 7 # Urban Planning
ccs[ccs$rowid=="a995", "v_5R"] <- 2 # Pharmacy
ccs[ccs$rowid=="a1058","v_5R"] <- 1 # Civil Engineering
ccs[ccs$rowid=="a1024","v_5R"] <- 1 # Engineering
ccs[ccs$rowid=="a1015","v_5R"] <- 1 # Industrial Engineering
ccs[ccs$rowid=="a1026","v_5R"] <- 1 # Civial Engineering
ccs[ccs$rowid=="a1030","v_5R"] <- 2 # Health science (occupational theory)
ccs[ccs$rowid=="a1102","v_5R"] <- 5 # Physical Education
ccs[ccs$rowid=="a1043","v_5R"] <- 4 # Interactive Media Design
ccs[ccs$rowid=="a1065","v_5R"] <- 7 # Urban Planning
ccs[ccs$rowid=="a1119","v_5R"] <- 7 # Urban Planning
ccs[ccs$rowid=="a1071","v_5R"] <- 1 # Automatation and Control Engineering
ccs[ccs$rowid=="a1091","v_5R"] <- 4 # Computer Science
ccs[ccs$rowid=="a1103","v_5R"] <- 1 # Transportation Engineering
ccs[ccs$rowid=="a1088","v_5R"] <- 4 # Transportion connected to Computer Science and Mathematics
ccs[ccs$rowid=="a1085","v_5R"] <- 3 # Sociology and Statistics
ccs[ccs$rowid=="a1115","v_5R"] <- 7 # Urban Planning
ccs[ccs$rowid=="a1078","v_5R"] <- 1 # Transportation
ccs[ccs$rowid=="b302","v_5R"] <-  1 # Biomedical engineering
ccs[ccs$rowid=="b313","v_5R"] <-  7 # Geography
ccs[ccs$rowid=="a1116","v_5R"] <- 1 # Control Engineering
ccs[ccs$rowid=="a1146","v_5R"] <- 2 # Human physiology
ccs[ccs$rowid=="a1158","v_5R"] <- 2 # Pharmacy
ccs[ccs$rowid=="a1172","v_5R"] <- 1 # Material science and engineering
ccs[ccs$rowid=="a1194","v_5R"] <- 7 # Architecture and planning
ccs[ccs$rowid=="a1191","v_5R"] <- 1 # Transport planning
ccs[ccs$rowid=="a1181","v_5R"] <- 4 # Statistics
ccs[ccs$rowid=="a1215","v_5R"] <- 7 # Land use and trasnport plannig
ccs[ccs$rowid=="a1224","v_5R"] <- 2 # Medicine
ccs[ccs$rowid=="a1290","v_5R"] <- 1 # Material sciences
ccs[ccs$rowid=="a1292","v_5R"] <- 1 # Mechanical, Control engineering
ccs[ccs$rowid=="a1297","v_5R"] <- 3 # Administration
ccs[ccs$rowid=="a1288","v_5R"] <- 2 # Health care
ccs[ccs$rowid=="a1284","v_5R"] <- 2 # Health care
ccs[ccs$rowid=="a1269","v_5R"] <- 2 # Nursing
ccs[ccs$rowid=="a1281","v_5R"] <- 2 # Physiotherapy


#' Everything recodified?
ccs %>% filter(as.numeric(v_5R)==10) %>% select(rowid, v_223)


#' Create STEM - NON-STEM variable
ccs$v_5STEM <- as_label(ccs$v_5R)
levels(ccs$v_5STEM) <- list("STEM"=c("Chemistry, Physics & Engineering",
                                     "Life Science & Medical Science",
                                     "Computer Science & Mathematics",
                                     "Agriculture & Food Science",
                                     "Biology, Environmental Science & Geography"),
                        "Non-STEM"=c("Sociology, Economics & Political Science",
                                      "Psychology & Education",
                                      "Humanities" ))


#' v_6 Birth year
#' Fix birth year entries. Some have format "67" while others use four digits "1967"
#' Make full year for all entries.
ccs$v_6 <- ifelse((ccs$v_6>0 & ccs$v_6<100), (ccs$v_6+1900), ccs$v_6)

#' Correct birth year typos
ccs[ccs$rowid=="a847","v_6"] <- 1963 #typ0 2963
ccs[ccs$rowid=="a887","v_6"] <- 1969 #typo 169

#' calculate Age
ccs$Age <- current_year - ccs$v_6


#' Gender v_7
#' Recodify to v_7R
ccs$v_7R <- ccs$v_7

#' check all "Other" and show which option selected.
#' filter(ccs, v_7==3) %>% select(rowid, v_7, v_9)

ccs[ccs$rowid=="a262", "v_7R"] <- NA # replace Other by NA
ccs[ccs$rowid=="a258", "v_7R"] <- 2  # replace Other by 'man'
ccs[ccs$rowid=="a898", "v_7R"] <- 1  # replace Other by "woman"
ccs[ccs$rowid=="a924", "v_7R"] <- 1
ccs[ccs$rowid=="a1019", "v_7R"]<- 1


#' v_11 Team tenure.
ccs$v_11 <- ifelse(ccs$v_11 > 2018, NA, ccs$v_11)
ccs$v_11 <- ifelse(ccs$v_11 < 18, (ccs$v_11+2000), ccs$v_11) # replace 12, 14, 15 with 2012, 2014, etc.
ccs[ccs$rowid=="a99", "v_11"] <- 2000 # replace 200 with 2000

#' Calcualte team tenure in years
ccs$YrsInTeam <- current_year - ccs$v_11



#' v_12 Current role
#' 1 MA Student
#' 2 PhD Student
#' 3 Research or lab assistant / technician
#' 4 Postdoc / Junior researcher
#' 5 Senior researcher
#' 6 Team leader
#' 7 Other, please specify: &nbsp;
#' 8 Administration
#'
#' See attr(ccs$v_12, "labels")
#' Print "Other":
ccs %>% filter(as.numeric(v_12)==7) %>% select(rowid, v_18)


ccs$v_12R <- add_labels(ccs$v_12, labels=c("Administration" = 8))

ccs[ccs$rowid=="a108", "v_12R"] <- 8 # -- Admin is Assistant/Technician
ccs[ccs$rowid=="a200", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a193", "v_12R"] <- 3 # In charge of imaging
ccs[ccs$rowid=="a114", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a73", "v_12R"]  <- 1 # Erasmus student - would be BA student?
ccs[ccs$rowid=="a89", "v_12R"]  <- 8 # Personal assistant
ccs[ccs$rowid=="a132", "v_12R"] <- 5 # Lecturer + researcher
ccs[ccs$rowid=="a209", "v_12R"] <- 5 # Tenured scientist
ccs[ccs$rowid=="a129", "v_12R"] <- 2 # Technician + PhD Student
ccs[ccs$rowid=="a160", "v_12R"] <- 6 # Junior PI
ccs[ccs$rowid=="a168", "v_12R"] <- 6 # Division Leader
ccs[ccs$rowid=="a122", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a198", "v_12R"] <- 5 # Emeritus profesor
ccs[ccs$rowid=="a414", "v_12R"] <- 1 # MA student
ccs[ccs$rowid=="a314", "v_12R"] <- 4 # after Phd, no formal position
ccs[ccs$rowid=="a278", "v_12R"] <- 2 # Industrial PhD
ccs[ccs$rowid=="a262", "v_12R"] <- 3 # ++ Research engineer
ccs[ccs$rowid=="a409", "v_12R"] <- NA# BA student - create category?
ccs[ccs$rowid=="a438", "v_12R"] <- NA# -99
ccs[ccs$rowid=="a271", "v_12R"] <- NA# BA student - create category?
ccs[ccs$rowid=="a432", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a355", "v_12R"] <- 8 # Research + Innovation Manager
ccs[ccs$rowid=="a378", "v_12R"] <- 6 # Co-leader
ccs[ccs$rowid=="a446", "v_12R"] <- 3 # Lab technician
ccs[ccs$rowid=="a444", "v_12R"] <- NA# oldmate
ccs[ccs$rowid=="a552", "v_12R"] <- 5 # ++ Research Engineer
ccs[ccs$rowid=="a768", "v_12R"] <- 4 # Junior researcher, not employed
ccs[ccs$rowid=="a452", "v_12R"] <- 5 # ++ Research Engineer
ccs[ccs$rowid=="a748", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a456", "v_12R"] <- NA# up there
ccs[ccs$rowid=="a564", "v_12R"] <- NA# consult
ccs[ccs$rowid=="a755", "v_12R"] <- 4 # Junior analyst
ccs[ccs$rowid=="a519", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a553", "v_12R"] <- 8 # Communications Officer
ccs[ccs$rowid=="a518", "v_12R"] <- 5 # Senior lecturer
ccs[ccs$rowid=="a535", "v_12R"] <- 4 # Postdoc
ccs[ccs$rowid=="a479", "v_12R"] <- 5 # Senior advisor
ccs[ccs$rowid=="a500", "v_12R"] <- NA# partners in the project
ccs[ccs$rowid=="a551", "v_12R"] <- 5 # Research collaborator
ccs[ccs$rowid=="a664", "v_12R"] <- 5 # Research collaborator
ccs[ccs$rowid=="a568", "v_12R"] <- 5 # Academic clinical fellow
ccs[ccs$rowid=="a665", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a563", "v_12R"] <- 8 # Patient involvement manager
ccs[ccs$rowid=="a737", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a608", "v_12R"] <- 3 # Research technician with own project and helping in others
ccs[ccs$rowid=="a641", "v_12R"] <- 5 # Research associate
ccs[ccs$rowid=="a645", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a648", "v_12R"] <- 8 # Project Assistant
ccs[ccs$rowid=="a683", "v_12R"] <- NA# Education
ccs[ccs$rowid=="a680", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a712", "v_12R"] <- NA# Simply work here
ccs[ccs$rowid=="a763", "v_12R"] <- 8 # -- Admin staff
ccs[ccs$rowid=="a825", "v_12R"] <- 5 # Teaching / lecturer
ccs[ccs$rowid=="a765", "v_12R"] <- 2 # Phd Student
ccs[ccs$rowid=="a826", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="a833", "v_12R"] <- 1 # MA student
ccs[ccs$rowid=="b47", "v_12R"] <-  8 # -- Admin
ccs[ccs$rowid=="b58", "v_12R"] <-  8 # ** Project manager
ccs[ccs$rowid=="b80", "v_12R"] <-  5 # External researcher
ccs[ccs$rowid=="b261", "v_12R"] <- 8 # QA
ccs[ccs$rowid=="b262", "v_12R"] <- NA# Specialist
ccs[ccs$rowid=="b264", "v_12R"] <- 8 # -- Admin
ccs[ccs$rowid=="b272", "v_12R"] <- 3 # Student assistant
ccs[ccs$rowid=="b291", "v_12R"] <- 5 # Meister
ccs[ccs$rowid=="b292", "v_12R"] <- 8 # ** Project manager
ccs[ccs$rowid=="c72", "v_12R"] <-  5 # ++ Research Engineer
ccs[ccs$rowid=="c138", "v_12R"] <- 8 # ** Project Manager  -> Should be codified as "8"
ccs[ccs$rowid=="a867", "v_12R"] <- 5 # Affiliated researcher
ccs[ccs$rowid=="a888", "v_12R"] <- 3 # ICT Specialist
ccs[ccs$rowid=="a883", "v_12R"] <- 5 # Researcher
ccs[ccs$rowid=="a926", "v_12R"] <- 8 # ** Project Manager
ccs[ccs$rowid=="a964", "v_12R"] <- 3 # Lab Manager
ccs[ccs$rowid=="a966", "v_12R"] <- 3 # Programmer
ccs[ccs$rowid=="a1040", "v_12R"] <-8 # ** Project Manager
ccs[ccs$rowid=="a961", "v_12R"] <- 5 # Fellow ??
ccs[ccs$rowid=="a1024", "v_12R"] <-5 # Professor
ccs[ccs$rowid=="a1004", "v_12R"] <-5 # Visiting scholar
ccs[ccs$rowid=="a1006", "v_12R"] <-5 # Visiting scholar
ccs[ccs$rowid=="a1103", "v_12R"] <-5 # Medior Research/analyst
ccs[ccs$rowid=="a1123", "v_12R"] <-8 # -- Research Admin
ccs[ccs$rowid=="a1158", "v_12R"] <-5 # Associate Professor
ccs[ccs$rowid=="a1203", "v_12R"] <-8 # ** Manager
ccs[ccs$rowid=="a1194", "v_12R"] <-5 # Researcher
ccs[ccs$rowid=="a1293", "v_12R"] <-6 # Clinician co-team leader
ccs[ccs$rowid=="a1228", "v_12R"] <-3 # Clinical geneticist
ccs[ccs$rowid=="a1235", "v_12R"] <-5 # Gynecol. Consultat
ccs[ccs$rowid=="a1267", "v_12R"] <-5 # Senior scientist
ccs[ccs$rowid=="a1288", "v_12R"] <-3 # Nurse / assistant
ccs[ccs$rowid=="a1284", "v_12R"] <-3 # Nurse / assistant
ccs[ccs$rowid=="a1269", "v_12R"] <-1 # Study nurse

#' check if all has been recodified
ccs %>% filter(as.numeric(v_12R)==7) %>% select(rowid, v_18)


#' Recode character numbers to real ones.
#'
ccs[ccs$rowid=="a132","v_97"] <- "1"  # "one" to 1
ccs[ccs$rowid=="a241","v_97"] <- "1"  # "one" to 1
ccs[ccs$rowid=="a1044","v_97"] <- "1" # "one" to 1


#' remove test group junk
ccs <- filter(ccs, v_1 != "TestGroup")

#' read team size info and calculate percentage of responses
#' The CSV file needs updating when new entries are available.
#' The team size file come from GEDII_xcountry_participation.
#teamsize <- read_tsv("~/limbo/GEDII/teamsize.csv")
teamsize <- read_gpg("data-raw/df.teamsize.gpg")

ccs <- left_join(ccs, teamsize, by=c("v_1" = "TeamID"))


#' calculate response total per group and percentage
resp <- ccs %>%
  filter(dispcode > 22) %>%
  group_by(v_1) %>%
  count(v_1)

ccs <- left_join(ccs, resp, by=c("v_1"))
ccs$resprate <- ccs$n / ccs$Total

#rename Total and n
ccs <- rename(ccs, teamsize = Total, resptotal = n)


#' Create "country" variable. Requires reading the group codes
#' which contain the information to which country team belongs.
#'

country.code <- data.frame(Country=c("Germany", "Spain", "Sweden", "Great Britain",
                                     "Lithuania", "Netherlands", "Belgium", "Poland", "Czech Republic",
                                     "Austria", "Switzerland", "Denmark", "Norway", "Finland", "Portugal", "Italy", "France"),
                           Code = c("G", "E", "S", "B", "L", "N", "U", "P", "R", "A", "Z", "K", "W", "F", "O", "Y", "C"),
                           stringsAsFactors = F)


ccs <- ccs %>%
  mutate(ccode=str_sub(v_1,1,1)) %>%
  left_join(country.code, by=c("ccode"="Code")) %>%
  select(-ccode)



#' Store the merged PURE survey dataset in RDATA format
#'
#'
if (saveXLS){
  filepath <- paste0("GEDII_xcountry_", format(Sys.time(), "%b%d_%Y"), ".RDATA")
  save(ccs, file = filepath)
}



#' MERGE WITH TEAM CONTACT
#'
#' Team contact entires have been read and prepared previously (see start of this file).

#' adjust attributes to avoid warning
attributes(ccsc$GroupCode) <- NULL

#' Check if there are duplicated entries for the team contact
#' dataframe should be empty!
tmp <- ccsc %>%
    group_by(GroupCode) %>%
    filter(n()>1) %>%
    arrange(GroupCode)

if (nrow(tmp) > 0){
  stop("One or more entries found for same group in Team Contact data!")
}

#' There are some entries in the team contact questionnaire for which no
#' team members have answered. Here we ignore those and only include the
#' team contact questionnaire for those groups where at least one team member has
#' answered.
ccs <- ccs %>%
  left_join(ccsc, by=c("v_1"="GroupCode"))

#'remove lfdn columns
ccs <- select(ccs, -c(lfdn.x, lfdn.y))




#' GENDER-DIVERSITY-INDEX
#'
#' Read global GDI score and add to ccs
df.gdi <- read_gpg("data-raw/df.GEDII_GDI_Pillars_8JAN2019.xlsx.gpg")

# df.gdi <- select(df.gdi, "v_1"=2, "Index.6"=3)
# df.gdi <- unique(df.gdi)
ccs <- ccs %>%
  left_join(df.gdi, by="v_1")




#' PERFORMANCE DATA
#'
#' Construct performance data matrix. This involves compilation of individual xls files for each group
#' where the "Indicator" sheet is read which contains 13 performance indicators listed by each
#' team member. We only retain the summary across all team members for the group.
#'
#' There also exists some global indicators on the group level, such as the PM Model or FAP indicator.
#' This is an extra xls file that is read and merged with the performance data frame.
#'
#' Then, the patents xls file is read and merged. No fractional counts are done for patents yet,
#' although this could be possible.
#'


#' Reads xlsx file with biliometric performance data. The summary information is contained in
#' the "Indicators" sheet.  The Sheet contains bibliometric info for each author of the team.
#' However, for merging with the survey data, only the total should be retained.
#'
#' @param filepath String indicating the complete filepath to the xlsx performance file
#' @param sheet String indicating the summary sheet of the bibliometric info of the team
#' @param group.codes Dataframe containing two columns matching the group number (of the file name)
#' with the internal group code. The column of the group number is "GroupNumber", the columnn for the code
#' "GroupCode".
#' @param report.total Bool indicating if the bibliometric info of all authors is returned or just
#' the group total.
#'
#' @return Dataframe containing either group total or total + individual author bibliometric performance
#' data.
read.performance <- function(filepath, group.codes=NULL, sheet="Indicators", report.total=T){

  #' extract group number from filepath
  grp <- regmatches(filepath, regexpr("Grp\\s[0-9]+", filepath))

  df <- tryCatch(
      read_excel(filepath, sheet=sheet, col_names = T),

      error = function(er_msg){
        message(er_msg, " in file ", grp)
      }


  )

  if (is.null(df)){
    stop("Stopping")
  }

  if (ncol(df) != 14){
    stop("Number of columns does not match in", grp)
  }

  #' unify col names
  names(df) <- c("Author",
                    "CountFullBMXID",
                    "CountFracBMXID",
                    "AvgFracNCSj",
                    "AvgFracNJCS",
                    "AvgFracNCSf",
                    "AvgFracNCSf2y",
                    "AvgFracTOP1",
                    "AvgFracTOP5",
                    "AvgFracTOP10",
                    "AvgFracTOP25",
                    "AvgFracTOP50",
                    "AvgFracAUm",
                    "AvgFracIntCOLLm")



  #' add group number to xls dataframe
  df$GroupNumber <- as.numeric(substr(grp, 5, nchar(grp)))

  #' add (match) the group number to the internal group code
  if (!is.null(group.codes)){
    df <- df %>% left_join(group.codes, by="GroupNumber")
  }

  if (report.total){
    #df <- df[which(df[1] == "Total"),]
    df <- filter(df, Author=="Total")
  }

  df
}



#' listing of all xlsx sheets, one per group.
#' Grp 6, columns don't match
files.grp  <- list.files(paste0("group xls/"), pattern="*.xlsx", full.names=TRUE)

#' Matching group numbers (of file names) and group codes
grpcode <- read_gpg("data-raw/df.grpcode.gpg")

#' remove case study
grpcode <- filter(grpcode, GroupCode != "Case Study")


#' read all bibliometric performance files
perf <- lapply(files.grp, read.performance, group.codes=grpcode)

#' bind them together and remove first column  (Total)
df.perf <- do.call(rbind, perf)
df.perf <- select(df.perf, -Author)

#' get rid of case studies
df.perf <- filter(df.perf, (!GroupNumber %in% 134:139))


#' load global bibliometric performance data which comes in extra file
df.perf.pm <- read_gpg("data-raw/df.Results_Bibliometrics_Global_15JAN2018.xlsx.gpg")


#' Select some columns only
df.perf.pm <- select(df.perf.pm,c(1,7,8,10,16,17))
names(df.perf.pm) <- c("GroupNumber","FAP", "PMM", "NrSeniorBib", "OutwardTotal", "InternatCollab")
df.perf.pm$GroupNumber <- as.numeric(df.perf.pm$GroupNumber)

#' get rid of case studies 134:139
df.perf.pm <- filter(df.perf.pm, (!GroupNumber %in% 134:139) & !is.na(GroupNumber) )

#' join full and global performance data frames
df.perf <- df.perf %>%
  full_join(df.perf.pm, by="GroupNumber")


#' load patent dataframe
df.perf.pat <- read_gpg("data-raw/df.Results_Patents_Global_15JAN2018.csv.gpg")
names(df.perf.pat) <- c("GroupCode", "NrPatents")


#' summary of nr patents for each group
#' using only entries where appln_id is not NA. Other patents could not
#' be assigned to team members.
# df.perf.pat <- df.perf.pat %>%
#   filter(!is.na(ApplicationID)) %>%
#   group_by(GroupCode) %>%
#   summarize(NrPatents = sum(NrPatents, na.rm=T))

#' join with bibliometric performance data
df.perf <- df.perf %>%
  left_join(df.perf.pat, by="GroupCode")


#' Correct team codes
df.perf[which(df.perf$GroupCode == "W115T1507U"), "GroupCode"] <- "WT115T1507U"
df.perf[which(df.perf$GroupCode == "Z116T1628U"), "GroupCode"] <- "ZT116T1628U"
df.perf[which(df.perf$GroupCode == "OT104T1253U"),"GroupCode"] <- "CT104T1253U"


#' arrange entries
df.perf <- df.perf %>% arrange(df.perf$GroupCode)


#' join with survey
ccs <- ccs %>%
  left_join(df.perf, by=c("v_1"="GroupCode"))



#' UPDATE 12 NOVEMBER 2018
#'
#' 1st correction of performance data. See CHANGELOG for details.
df.n <- read_gpg("data-raw/df.GEDII_TLD_NOV2018.xlsx.gpg")

colnames(df.n)[66] <- "Applied"               #get rid of "?" in column name
colnames(df.n)[77] <- "FAP5Y1000xNrSeniorBib" #get rid of "/" in column name
colnames(df.n)[81] <- "PM5Y1000xNrSeniorBib"
colnames(df.n)[79] <- "SubjectFieldDiv"


df.n %<>%
  mutate(Applied = as.factor(Applied),
         orgTYPEnew = factor(orgTYPEnew, levels=c(1,2,3), labels=c("University", "RPO", "Other"))) %>%
  transmute(v_1,
         # UPDATED 28 NOV (see below)
           FAP8Y1000_Nov18             = round(FAP1000,0),
           PMM8Y1000_Nov18             = round(PM_1000,0),
         # FAP5Y1000_Nov18             = round(FAP5Y_1000,0),
         # FAP5Y1000xNrSeniorBib_Nov18 = round(FAP5Y1000xNrSeniorBib,0),
         # PMM5Y1000_Nov18             = round(PM5_1000,0),
         # PMM5Y1000xNrSeniorBib_Nov18 = round(PM5Y1000xNrSeniorBib,0),
         # NrSeniorBib_Nov18           = TL_NrSeniorBib,
           ColocationBib_Nov18         = colocatedpb,
         # Inward_Nov18                = Inward, #updated with extra file (see below)
           OrgTypeR_Nov18              = orgTYPEnew,
           Field_Nov18                 = Field,
           Applied_Nov18               = Applied,
           CountryBib_Nov18            = Countrycode,
           SubjectFieldDiv_Nov18       = SubjectFieldDiv
         )

#' merge into main dataframe
ccs <- ccs %>%
  left_join(df.n, by="v_1")


#' update group number for "0" publication groups
#' previously no GroupNumber has been assigned, because these groups have "0" publications
#' Now they have been included in performance groups.
ccs[which(ccs$v_1 == "GT8T0914V"), "GroupNumber"] <- 30
ccs[which(ccs$v_1 == "GT3T0955U"), "GroupNumber"] <- 104



#' UPDATED BIBLIOMETRICS 28 NOVEMBER 2018
#'
#' 2nd correction of performance data + number of seniors
#' based on bibliometrics. See CHANGELOG.
#'
#' Performance data and leader gender data is mixed in xls file.
#' Needs to be extracted in two steps.
#'
rm(df.n)

#' Group 30 and 104 (0 performance) have been manually added. For new xls files, these need to be
#' updated again. Both have 1 senior bib, both leaders are men, with FAP/PM set to 10.
df.n <- read_gpg("data-raw/df.GEDII_SeniorBIB_28NOV2018.xlsx.gpg")


#' extract performance data only
df.p <- df.n %>%
  group_by(Group) %>%
  filter(is.na(Name)) %>%
  transmute(GroupNumber                 = Group,
            NrSeniorBib_Nov18           = NrSeniorBib,
            FAP5Y_Nov18                 = FAP5,
            PMM5Y_Nov18                 = PM5,
            PMM5Y1000_Nov18             = round(PMM5Y_Nov18*1000,0),
            FAP5Y1000_Nov18             = round(FAP5Y_Nov18*1000,0),
            FAP5Y1000xNrSeniorBib_Nov18 = round(FAP5Y1000_Nov18/NrSeniorBib_Nov18,0),
            PMM5Y1000xNrSeniorBib_Nov18 = round(PMM5Y1000_Nov18/NrSeniorBib_Nov18,0)
  )


ccs <- ccs %>%
  left_join(df.p, by="GroupNumber")

rm(df.p)
rm(df.n)



#' create factor for team type based upon senior bib
#' and add exceptions to that. See CHANGELOG and the file GEDII_TeamType_19DEC2018.xlsx
ccs$TeamType_Nov18 <- ccs$NrSeniorBib_Nov18
ccs$TeamType_Nov18 <- factor(ccs$TeamType_Nov18)
levels(ccs$TeamType_Nov18) <- list("1 Senior" = c(0,1),
                                   "2-3 Seniors" = c(2,3),
                                   "4-5 Seniors" = c(4,5),
                                   "6-7 Seniors" = c(6-7),
                                   "Other" = c(8:14))

ccs[which(ccs$v_1 == "EM11M1231U"), "TeamType_Nov18"] <- "Other"       #Group 7 with 5 seniors
ccs[which(ccs$v_1 == "SM25M1436U"), "TeamType_Nov18"] <- "2-3 Seniors" # Group 68
ccs[which(ccs$v_1 == "EM44F0800U"), "TeamType_Nov18"] <- "6-7 Seniors" # Group 35
ccs[which(ccs$v_1 == "ST10T1352U"), "TeamType_Nov18"] <- "6-7 Seniors" # Group 74

ccs[which(ccs$GroupNumber %in% c(1,23,38,50,70,78,102,108,123,125,127)), "TeamType_Nov18"] <- "Other"




#' UPDATE 28 NOVEMBER 2018
#'
#' update inward and inward normalized (now based upon 5 years bibliometric data)
#'
df.n <- read_gpg("data-raw/df.GEDII_Inward_5YRS_28NOV2018.xlsx.gpg")

df.n %<>%
  transmute(GroupNumber         = Group,
            Inward_Nov18        = Inward2,
            InwardAvgRef_Nov18  = AvgREF,
            InwardNorm_Nov18    = Inward3,
            InwardNormMedian_Jan19 = InwardMedianNorm_Jan04,
            InternatCollab = InternatCollab)

ccs <- ccs %>%
  select(-InternatCollab) %>%
  left_join(df.n, by="GroupNumber")


#' Superseded by above update.
#' Normalize "inward" based upon field.
# ccs$InwardNormFac <- NA
# ccs[which(ccs$Field_Nov18 == "Applied"), "InwardNormFac"] <- 0.872
# ccs[which(ccs$Field_Nov18 == "EcSoc"),   "InwardNormFac"] <- 0.632
# ccs[which(ccs$Field_Nov18 == "Health"),  "InwardNormFac"] <- 1.370
# ccs[which(ccs$Field_Nov18 == "Natural"), "InwardNormFac"] <- 1.465
#
# ccs$InwardNorm_Nov18 <- ccs$Inward_Nov18/ccs$InwardNormFac


#' Convert scientific field to factor
ccs$Field_Nov18 <- as.factor(ccs$Field_Nov18)


#' create integers for (old) performance data
ccs$FAP1000 <- round(ccs$FAP*1000, 0)
ccs$PMM1000 <- round(ccs$PMM*1000, digits=0)


#' Power / influence
ccs %<>%
  mutate(PInflu = rowMeans(.[,paste("v", c(143:145), sep="_")], na.rm=T) )


#' Team climate aggregates
ccs %<>%
  mutate(Tclimate = rowMeans(.[,paste("v", c(151:164), sep="_")], na.rm=T),
         TcliVision = rowMeans(.[,paste("v", c(151:155), sep="_")], na.rm=T),
         TcliSafety = rowMeans(.[,paste("v", c(156:158), sep="_")], na.rm=T),
         TcliTask = rowMeans(.[,paste("v", c(159:161), sep="_")], na.rm=T),
         TcliInno = rowMeans(.[,paste("v", c(152:164), sep="_")], na.rm=T))


#' Team leadership
ccs %<>%
  mutate(Leadstyle = rowMeans(.[,paste("v", c(170:177), sep="_")], na.rm=T),
         LeadIM = rowMeans(.[,paste("v", c(170:171), sep="_")], na.rm=T),
         LeadIC = rowMeans(.[,paste("v", c(172:173), sep="_")], na.rm=T),
         LeadIS = rowMeans(.[,paste("v", c(174:175), sep="_")], na.rm=T),
         LeadII = rowMeans(.[,paste("v", c(176:177), sep="_")], na.rm=T))


#' Working climate
ccs %<>%
  mutate(Wclimate = rowMeans(.[,paste("v", c(186:187), sep="_")], na.rm=T))


#' Gender Stereotypes
ccs %<>%
  mutate(Gstereo = rowMeans(.[,paste("v", c(195:198), sep="_")], na.rm=T))

#' Logical senior researcher based on experience: if more than 10 years of experience
ccs %<>%
  mutate(isSeniorExp = if_else(v_83<=3, 0, 1))

#' Construc different role (groups)
ccs %<>%
  mutate(isSeniorRole    = if_else((v_12R == 5 | v_12R == 6), 1, 0),
         isPhDRole       = if_else(v_12R == 2, 1, 0),
         isAdminRole     = if_else(v_12R == 8, 1, 0),
         isPostdocRole   = if_else(v_12R == 4, 1, 0),
         isAssistantRole = if_else(v_12R == 3, 1, 0),
         isMARole        = if_else(v_12R == 1, 1, 0),
         isJuniorRole    = if_else((v_12R == 4 | v_12R == 2), 1, 0),
         isNonBibRole    = if_else((Age < 29 & v_11 > 2014) | (v_12R == 1 | v_12R == 8), 1, 0))


#' Logical gender variable for easy counting globally
#' as well as for the NonBibRole to calculate the gender distribution of people potentially
#' removed
ccs %<>%
  mutate(isWoman = if_else(v_7R == 1, 1, 0),
         isMan   = if_else(v_7R == 2, 1, 0),
         isWomanNonBibRole = if_else((v_7R == 1 & isNonBibRole==1), 1, 0),
         isManNonBibRole   = if_else((v_7R == 2 & isNonBibRole==1), 1, 0))

#' Calculate for the team level how many women or men will be removed
ccs %<>%
  group_by(v_1) %>%
  mutate(TL_NrWomenNonBibRole = sum(isWomanNonBibRole, na.rm=T),
         TL_NrMenNonBibRole = sum(isManNonBibRole, na.rm=T)) %>%
  ungroup()


#' Frequency of Communication
ccs %<>%
  mutate(FrqCom = rowMeans(.[,paste("v", c(13:17), sep="_")], na.rm=T))

#' Has mentor
ccs %<>%
  mutate(v_63R = if_else(v_63==1, 1,0))

#' Type of contract
ccs %<>%
  mutate(hasPerm = if_else(v_80==2, 1,0),
         hasTemp = if_else(v_80==1, 1,0))

#' Time for pub. Option 6 is "not part of my responsibility"
ccs %<>%
  mutate(v_85R = if_else(v_85 == 6, 0, v_85))

#' Ethnic minority and disability
ccs %<>%
  mutate(v_100R = if_else(v_100 == 1, 1, 0),
         v_101R = if_else(v_101 == 1, 1, 0))

#' Care responsibility
ccs %<>%
  mutate(CareRespPresent = if_else(v_132 == 1 | v_120 == 1, 1, 0),
         CareRespPast    = if_else(v_119 == 1 | v_121 == 1, 1, 0),
         CareResp        = if_else(CareRespPresent == 1 | CareRespPast == 1, 1, 0))

#' care responsibility affects work
ccs %<>%
  mutate(CareDoesAffect = if_else(v_123 > 1, 1, 0))


#' store info which dataset is created and what is the
#' original teamsize based on recruited
ccs %<>%
  group_by(v_1) %>%
  mutate(teamsize_type = tss_type,
         teamsize_recruited = teamsize,
         teamsize_bib = teamsize - sum(isNonBibRole, na.rm=T))


#' remove "..1", "Group" var
ccs %<>%
  select(-154)

ccs %<>%
  select(-203)

ccs$GroupID <- sapply(ccs$v_1, digest, algo="md5")
ccs$GroupID <- substr(ccs$GroupID, 1,8)


#' which dataset will be created
if (tss_type == "recruited"){

  gedii_ccs <- ccs
  save(gedii_ccs, file = "data/gedii_ccs.rdata")

  message("\nRecruited teamsize dataset build and saved to gedii_ccs.rdata")

#' reduced teamsize dataset
} else if (tss_type == "bib"){

  #' assign teamsize bib as "real" teamsize
  ccs %<>%
    mutate(teamsize = teamsize_bib)

  # remove non bib contributors
  ccs %<>%
    filter(isNonBibRole != 1)

  gedii_ccsb <- ccs
  save(gedii_ccsb, file = "data/gedii_ccsb_enc.rdata")

  message("\nBib-teamsize dataset build and saved to gedii_ccsb.rdata")


} else {

  stop("Unknown tss_type. No dataset has been build")

}







